korean_word_dict = {
    "main_window_current_filename_format": "현재 파일 이름: {name}",
    # File menu
    "main_window_open_image": "파일 열기",
    "main_window_current_filename": "현재 파일 이름:",
    "main_window_current_file": "파일",
    "main_window_open_folder": "폴더 열기",
    "main_window_exit": "종료",
    "main_window_tile_size": "썸네일 크기",
    "main_window_select_folder": "폴더 선택",
    "main_window_select_image": "이미지 선택",
    "main_window_current_folder_format": "현재 폴더: {path}",
    "main_window_remove_undo_stack": "임시 되돌리기 파일 삭제",
    # Language Menubar
    "menu_bar_language": "언어",
    "language_menu_bar_please_restart_messagebox": "다시 시작해 주세요",
    "language_menu_bar_english": "영어",
    "language_menu_bar_traditional_chinese": "번체 중국어",
    "language_menu_bar_chinese": "간체 중국어",
    "language_menu_bar_koren": "한국어",
    "language_menu_bar_japanese": "일본어",
    # Tip menu
    "main_window_tip_menu": "사용 설명",
    "mouse_control_middle_tip": "마우스 휠 버튼으로 이동할 수 있습니다",
    "main_window_mouse_tip_menu": "마우스 조작",
    "main_window_keyboard_tip_menu": "키보드 조작",
    "mouse_control_left_tip": "마우스 왼쪽 버튼으로 이미지를 클릭하면 Deep zoom 모드로 들어갑니다",
    "mouse_control_multi_select_tip": "마우스 왼쪽 버튼을 누른 상태에서 썸네일 모드에서 여러 이미지를 선택할 수 있습니다",
    "keyboard_control_esc_tip": "Deep zoom 모드에서는 ESC 키로 종료할 수 있습니다",
    "keyboard_control_tile_arrow_up_tip": "썸네일 모드에서는 방향키 위로 위쪽으로 이동할 수 있습니다",
    "keyboard_control_tile_arrow_down_tip": "썸네일 모드에서는 방향키 아래로 아래쪽으로 이동할 수 있습니다",
    "keyboard_control_tile_arrow_left_tip": "썸네일 모드에서는 방향키 왼쪽으로 왼쪽으로 이동할 수 있습니다",
    "keyboard_control_tile_arrow_right_tip": "썸네일 모드에서는 방향키 오른쪽으로 오른쪽으로 이동할 수 있습니다",
    "keyboard_control_delete_tip": "Delete 키로 이미지를 휴지통으로 이동할 수 있습니다 (썸네일 및 Deep zoom 모드)",
    "keyboard_r_tip": "Deep zoom 모드에서 R / Shift+R로 시계/반시계 방향 회전",
    "keyboard_home_tip": "Home 키로 확대/축소 및 위치를 기본값으로 초기화",
    "keyboard_e_tip": "E 키로 이미지 편집기 열기",
    "keyboard_undo_tip": "마지막 작업을 실행 취소",
    "keyboard_redo_tip": "실행 취소한 작업을 다시 실행",
    "keyboard_arrow_lr_tip": "Deep zoom 모드에서 좌/우 키로 이미지 전환",
    "keyboard_arrow_tile_tip": "썸네일 모드에서 방향키로 이동",
    "tip_mouse_middle": "가운데 버튼",
    "tip_mouse_left_click": "왼쪽 클릭",
    "tip_mouse_left_drag": "왼쪽 드래그",
    "tip_mouse_right_desc": "컨텍스트 메뉴를 열어 다양한 작업 수행",
    "tip_mouse_scroll_desc": "스크롤로 확대/축소 또는 썸네일 스크롤",
    "tip_close": "닫기",
    "tip_show_shortcuts": "키보드 및 마우스 단축키",
    "keyboard_f_tip": "F 키로 전체화면 전환, Esc로 종료",
    "keyboard_ctrl_c_tip": "Ctrl+C로 현재 이미지를 클립보드에 복사",
    "keyboard_rating_tip": "1~5 키로 현재 이미지 평가; 다시 누르면 해제",
    "keyboard_search_tip": "/ 또는 Ctrl+F로 이미지 이름 검색",
    "keyboard_favorite_tip": "0 키로 현재 이미지 즐겨찾기 전환",
    "keyboard_slideshow_tip": "S 키로 슬라이드쇼 시작/중지",
    # 평가 상태
    "rating_set": "평가: {star}",
    "rating_cleared": "평가가 해제되었습니다",
    # 검색 다이얼로그
    "search_dialog_title": "이미지 검색",
    "search_dialog_placeholder": "검색어를 입력하세요...",
    "search_open": "열기",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "상위 폴더로 이동",
    "right_click_menu_next_image": "다음 이미지",
    "right_click_menu_previous_image": "이전 이미지",
    "right_click_menu_delete_current": "현재 이미지 삭제",
    "right_click_menu_delete_selected": "선택한 이미지 삭제",
    "right_click_menu_image_info": "이미지 정보",
    # Image info
    "image_info_filename": "파일명: {info}\n",
    "image_info_fullpath": "전체 경로: {full_path}\n",
    "image_info_image_size": "크기: {width} x {height}\n",
    "image_info_file_size": "파일 크기: {file_size_mb} MB\n",
    "image_info_file_created_time": "생성 시간: {created_time}\n",
    "image_info_file_modified_time": "수정 시간: {modified_time}\n",
    "image_info_messagebox_title": "이미지 정보",
    # Image info exif
    "image_info_exif_datatime_original": "촬영 시간: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "카메라: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "렌즈: {LensModel}\n",
    "image_info_exif_camera_focal_length": "초점 거리: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "조리개: {FNumber}\n",
    "image_info_exif_exposure_time": "셔터: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "최근 열린 메뉴",
    # Plugin
    "plugin_menu_title": "플러그인",
    "plugin_menu_loaded": "로드된 플러그인",
    "plugin_menu_no_plugins": "로드된 플러그인이 없습니다",
    "plugin_menu_reload": "플러그인 다시 로드",
    "plugin_menu_open_folder": "플러그인 폴더 열기",
    "plugin_info_name": "이름: {name}",
    "plugin_info_version": "버전: {version}",
    "plugin_info_author": "작성자: {author}",
    "plugin_info_description": "설명: {description}",
    "plugin_info_languages": "지원 언어: {languages}",
    "plugin_menu_manage": "플러그인 관리",
    "plugin_manage_count": "{count}개의 플러그인이 로드됨",
    "plugin_manage_select_hint": "플러그인을 선택하여 세부 정보를 확인하세요",
    "plugin_reload_confirm": "모든 플러그인을 다시 로드하시겠습니까? 현재 플러그인을 언로드하고 다시 검색합니다.",
    "plugin_reload_done": "{count}개의 플러그인을 다시 로드했습니다",
    "plugin_menu_download": "플러그인 다운로드",
    # Plugin Downloader
    "plugin_dl_title": "플러그인 다운로드",
    "plugin_dl_refresh": "새로 고침",
    "plugin_dl_col_name": "플러그인",
    "plugin_dl_col_status": "상태",
    "plugin_dl_download": "다운로드",
    "plugin_dl_reinstall": "재설치",
    "plugin_dl_delete": "삭제",
    "plugin_dl_close": "닫기",
    "plugin_dl_installed": "설치됨",
    "plugin_dl_not_installed": "미설치",
    "plugin_dl_status_ready": "준비 완료",
    "plugin_dl_status_fetching": "플러그인 목록을 가져오는 중...",
    "plugin_dl_status_found": "{count}개의 플러그인을 찾았습니다",
    "plugin_dl_status_error": "오류: {error}",
    "plugin_dl_status_downloading": "{name} 다운로드 중...",
    "plugin_dl_status_done": "{name} 다운로드 완료!",
    "plugin_dl_status_deleted": "{name}이(가) 삭제되었습니다.",
    "plugin_dl_restart_hint": "플러그인 '{name}'이(가) 다운로드되었습니다. Imervue를 다시 시작하여 활성화하세요.",
    "plugin_dl_delete_confirm_title": "플러그인 삭제",
    "plugin_dl_delete_confirm": "플러그인 '{name}'을(를) 삭제하시겠습니까?",
    # 우클릭 메뉴
    "right_click_show_in_explorer": "탐색기에서 표시",
    "right_click_copy_path": "경로 복사",
    "right_click_copy_image": "이미지 복사",
    "right_click_rotate_cw": "시계 방향 회전",
    "right_click_rotate_ccw": "반시계 방향 회전",
    "right_click_set_wallpaper": "배경화면으로 설정",
    "right_click_compare": "이미지 비교",
    "right_click_slideshow": "슬라이드쇼",
    "right_click_slideshow_stop": "슬라이드쇼 중지",
    # 정렬 메뉴
    "sort_menu_title": "정렬",
    "sort_by_name": "이름순",
    "sort_by_modified": "수정일순",
    "sort_by_created": "생성일순",
    "sort_by_size": "파일 크기순",
    "sort_by_resolution": "해상도순",
    "sort_ascending": "오름차순",
    "sort_descending": "내림차순",
    # 필터 메뉴
    "filter_menu_title": "필터",
    "filter_by_extension": "확장자별",
    "filter_by_rating": "평가별",
    "filter_ext_all": "전체",
    "filter_ext_jpg": "JPEG",
    "filter_ext_png": "PNG",
    "filter_ext_bmp": "BMP",
    "filter_ext_tiff": "TIFF",
    "filter_ext_raw": "RAW",
    "filter_rating_all": "전체",
    "filter_rating_favorited": "즐겨찾기",
    "filter_clear": "필터 해제",
    # 즐겨찾기
    "favorite_added": "\u2764 즐겨찾기에 추가됨",
    "favorite_removed": "즐겨찾기 해제됨",
    # 비교
    "compare_title": "이미지 비교",
    "compare_2": "2장 비교",
    "compare_4": "4장 비교",
    # EXIF 사이드바
    "exif_filename": "파일",
    "exif_filesize": "크기",
    "exif_created": "생성일시",
    "exif_modified": "수정일시",
    "exif_taken": "촬영일시",
    "exif_make": "제조사",
    "exif_model": "모델",
    "exif_lens": "렌즈",
    "exif_focal": "초점 거리",
    "exif_aperture": "조리개",
    "exif_shutter": "셔터 속도",
    "exif_iso": "ISO",
    "exif_ev": "노출 보정",
    "exif_wb": "화이트밸런스",
    "exif_flash": "플래시",
    "exif_resolution": "해상도",
    "exif_no_data": "EXIF 데이터 없음",
    # 슬라이드쇼
    "slideshow_title": "슬라이드쇼",
    "slideshow_interval": "간격 (초):",
    "slideshow_fade": "페이드 전환",
    "slideshow_start": "시작",
    "slideshow_cancel": "취소",
    # 상태 표시줄
    "status_loading_progress": "로딩 중 {current}/{total}...",
    "status_loading_image": "이미지 로딩 중...",
    "status_ready": "준비 완료",
    # Toast
    "toast_path_copied": "경로가 복사되었습니다",
    # 우클릭 추가
    "right_click_edit_image": "이미지 편집",
    "right_click_batch": "일괄 작업",
    "batch_rename_title": "일괄 이름 변경",
    "batch_rename_hint": "템플릿: {name} = 원래 이름, {n} = 일련번호, {ext} = 확장자",
    "batch_rename_start": "시작 번호:",
    "batch_rename_apply": "이름 변경",
    "batch_rename_cancel": "취소",
    "batch_move_title": "이동 / 복사",
    "batch_move_mode": "모드",
    "batch_move_move": "이동",
    "batch_move_copy": "복사",
    "batch_move_apply": "적용",
    "batch_move_cancel": "취소",
    "batch_rotate_cw": "모두 시계 방향 회전",
    "batch_rotate_ccw": "모두 반시계 방향 회전",
    # 이미지 편집기
    "editor_title": "이미지 편집기",
    "editor_brightness": "밝기",
    "editor_contrast": "대비",
    "editor_saturation": "채도",
    "editor_apply_crop": "자르기 적용",
    "editor_rotate_cw": "시계 방향 회전",
    "editor_rotate_ccw": "반시계 방향 회전",
    "editor_reset": "초기화",
    "editor_save_as": "다른 이름으로 저장...",
    "editor_save": "저장",
    "editor_saved": "저장되었습니다!",
    # EXIF 편집기
    "exif_edit_button": "EXIF 편집",
    "exif_editor_title": "EXIF 메타데이터 편집",
    "exif_editor_no_piexif": "piexif 패키지가 필요합니다.\n설치: pip install piexif",
    "exif_editor_fields": "메타데이터 필드",
    "exif_editor_save": "저장",
    "exif_editor_cancel": "취소",
    "exif_editor_close": "닫기",
    "exif_editor_saved": "EXIF가 저장되었습니다!",
    "exif_edit_description": "설명",
    "exif_edit_artist": "아티스트",
    "exif_edit_copyright": "저작권",
    "exif_edit_make": "제조사",
    "exif_edit_model": "모델",
    "exif_edit_user_comment": "사용자 코멘트",
    # 내보내기 대화상자
    "export_title": "이미지 내보내기",
    "export_format": "형식:",
    "export_quality": "품질:",
    "export_browse": "찾아보기...",
    "export_save": "저장",
    "export_cancel": "취소",
    "export_saved": "내보내기 완료!",
    # 히스토그램
    "histogram_toggle": "H 키로 RGB 히스토그램 전환",
    # 무손실 회전
    "lossless_rotate_cw": "무손실 시계 방향 회전",
    "lossless_rotate_ccw": "무손실 반시계 방향 회전",
    "lossless_rotate_done": "무손실 회전이 저장되었습니다!",
    "lossless_rotate_fail": "무손실 회전 실패",
    # 우클릭 메뉴 추가
    "right_click_export": "내보내기 / 다른 이름으로 저장...",
    "right_click_lossless_rotate": "무손실 회전",
    # 애니메이션 재생
    "anim_play": "재생",
    "anim_pause": "일시 정지",
    "anim_frame_prev": "이전 프레임",
    "anim_frame_next": "다음 프레임",
    "anim_frame_indicator": "프레임 {current}/{total}",
    "anim_speed": "속도: {speed}x",
    # 파일 연결
    "file_assoc_menu": "파일 연결",
    "file_assoc_register": "'Imervue로 열기' 등록",
    "file_assoc_unregister": "파일 연결 제거",
    "file_assoc_done": "파일 연결이 등록되었습니다!",
    "file_assoc_removed": "파일 연결이 제거되었습니다!",
    "file_assoc_need_admin": "관리자 권한 필요",
    # 다중 창
    "menu_new_window": "새 창",
    # 맞춤 모드
    "fit_width": "너비 맞춤",
    "fit_height": "높이 맞춤",
    "keyboard_w_tip": "W로 너비 맞춤, Shift+W로 높이 맞춤",
    # 추가 키보드 힌트
    "keyboard_h_tip": "딥줌 모드에서 H 키로 RGB 히스토그램 전환",
    "keyboard_ctrl_v_tip": "Ctrl+V로 클립보드에서 이미지 붙여넣기",
    "keyboard_anim_play_tip": "스페이스 키로 애니메이션 이미지(GIF/APNG/WebP) 재생/일시 정지",
    "keyboard_anim_frame_tip": "< / >로 애니메이션 프레임 이동",
    "keyboard_anim_speed_tip": "[ / ]로 애니메이션 속도 조절",
    # 북마크
    "bookmark_title": "북마크",
    "bookmark_open": "열기",
    "bookmark_remove": "삭제",
    "bookmark_clear": "모두 삭제",
    "bookmark_close": "닫기",
    "bookmark_count": "{count}개의 북마크된 이미지",
    "bookmark_added": "\u2605 북마크 추가됨",
    "bookmark_removed": "북마크 해제됨",
    "bookmark_add_current": "북마크에 추가",
    "bookmark_remove_current": "북마크 해제",
    "bookmark_clear_confirm_title": "북마크 삭제",
    "bookmark_clear_confirm": "모든 북마크를 삭제하시겠습니까?",
    "keyboard_b_tip": "B 키로 현재 이미지 북마크 전환",
    # SVG
    "filter_ext_svg": "SVG",
    # 태그 & 앨범
    "tag_album_title": "태그 & 앨범",
    "tag_tab_tags": "태그",
    "tag_tab_albums": "앨범",
    "tag_close": "닫기",
    "tag_count": "{count}개의 태그",
    "tag_create": "새 태그",
    "tag_rename": "이름 변경",
    "tag_delete": "삭제",
    "tag_images": "태그의 이미지:",
    "tag_remove_image": "태그에서 제거",
    "tag_filter": "뷰어에서 보기",
    "tag_create_prompt": "태그 이름:",
    "tag_rename_prompt": "새 이름:",
    "tag_delete_confirm_title": "태그 삭제",
    "tag_delete_confirm": "태그 '{name}'을(를) 삭제하시겠습니까?",
    "tag_menu_title": "태그",
    "tag_create_and_add": "+ 새 태그...",
    "album_count": "{count}개의 앨범",
    "album_create": "새 앨범",
    "album_rename": "이름 변경",
    "album_delete": "삭제",
    "album_images": "앨범의 이미지:",
    "album_remove_image": "앨범에서 제거",
    "album_view": "앨범 보기",
    "album_create_prompt": "앨범 이름:",
    "album_rename_prompt": "새 이름:",
    "album_delete_confirm_title": "앨범 삭제",
    "album_delete_confirm": "앨범 '{name}'을(를) 삭제하시겠습니까?",
    "album_menu_title": "앨범",
    "album_create_and_add": "+ 새 앨범...",
    "batch_tag_title": "태그에 추가",
    "batch_album_title": "앨범에 추가",
    "filter_by_tag": "태그별",
    "filter_by_album": "앨범별",
    "filter_no_tags": "(태그 없음)",
    "filter_no_albums": "(앨범 없음)",
    "keyboard_t_tip": "T 키로 태그 & 앨범 관리 열기",
    # 일괄 내보내기
    "batch_export_title": "일괄 내보내기",
    "batch_export_count": "{count}개의 이미지 선택됨",
    "batch_export_resize": "크기 조정",
    "batch_export_max_width": "최대 너비:",
    "batch_export_max_height": "최대 높이:",
    "batch_export_start": "내보내기",
    "batch_export_done": "{success}/{total}개의 이미지를 내보냈습니다",
    # GIF / 동영상
    "gif_video_title": "GIF / 동영상 만들기",
    "gif_video_order": "드래그하여 순서 변경 (위 = 첫 프레임):",
    "gif_video_move_up": "위로",
    "gif_video_move_down": "아래로",
    "gif_video_settings": "설정",
    "gif_video_fps": "FPS:",
    "gif_video_width": "너비:",
    "gif_video_height": "높이:",
    "gif_video_auto": "자동",
    "gif_video_loop": "무한 반복",
    "gif_video_create": "만들기",
    "gif_video_save": "다른 이름으로 저장",
    "gif_video_done": "생성 완료: {path}",
}
