traditional_chinese_word_dict = {
    "main_window_current_filename_format": "目前檔名： {name}",
    # File menu
    "main_window_open_image": "開啟檔案",
    "main_window_current_filename": "目前檔名：",
    "main_window_current_file": "檔案",
    "main_window_open_folder": "開啟資料夾",
    "main_window_exit": "離開",
    "main_window_tile_size": "縮圖大小",
    "main_window_select_folder": "選擇資料夾",
    "main_window_select_image": "選擇圖片",
    "main_window_current_folder_format": "目前資料夾： {path}",
    "main_window_remove_undo_stack": "刪除暫存撤銷檔案",
    # Language Menubar
    "menu_bar_language": "語言",
    "language_menu_bar_please_restart_messagebox": "請重新啟動",
    "language_menu_bar_english": "英文",
    "language_menu_bar_traditional_chinese": "繁體中文",
    "language_menu_bar_chinese": "簡體中文",
    "language_menu_bar_koren": "韓文",
    "language_menu_bar_japanese": "日文",
    # Tip menu
    "main_window_tip_menu": "使用說明",
    "main_window_mouse_tip_menu": "滑鼠操作",
    "main_window_keyboard_tip_menu": "鍵盤操作",
    "mouse_control_middle_tip": "可以使用滑鼠中鍵移動",
    "mouse_control_left_tip": "滑鼠左鍵點擊圖片可以進入 Deep zoom 模式",
    "mouse_control_multi_select_tip": "滑鼠左鍵按住可以在縮圖模式下複選圖片",
    "keyboard_control_esc_tip": "Deep zoom 模式下可以按 ESC 退出",
    "keyboard_control_tile_arrow_up_tip": "縮圖模式下可以使用方向鍵的上來往上移動",
    "keyboard_control_tile_arrow_down_tip": "縮圖模式下可以使用方向鍵的下來往下移動",
    "keyboard_control_tile_arrow_left_tip": "縮圖模式下可以使用方向鍵的左來往左移動",
    "keyboard_control_tile_arrow_right_tip": "縮圖模式下可以使用方向鍵的右來往右移動",
    "keyboard_control_delete_tip": "按 Delete 將圖片移至資源回收桶（縮圖和 Deep zoom 模式皆可）",
    "keyboard_r_tip": "Deep zoom 模式下按 R / Shift+R 順時針/逆時針旋轉",
    "keyboard_home_tip": "按 Home 重置縮放與位置至預設值",
    "keyboard_e_tip": "按 E 開啟圖片編輯器",
    "keyboard_undo_tip": "復原上一步操作",
    "keyboard_redo_tip": "重做上一步被復原的操作",
    "keyboard_arrow_lr_tip": "Deep zoom 模式下按左/右鍵切換圖片",
    "keyboard_arrow_tile_tip": "縮圖模式下使用方向鍵瀏覽圖片",
    "tip_mouse_middle": "中鍵",
    "tip_mouse_left_click": "左鍵點擊",
    "tip_mouse_left_drag": "左鍵拖曳",
    "tip_mouse_right_desc": "開啟右鍵選單，提供多種操作功能",
    "tip_mouse_scroll_desc": "滾輪縮放或捲動縮圖",
    "tip_close": "關閉",
    "tip_show_shortcuts": "鍵盤與滑鼠快捷鍵",
    "keyboard_f_tip": "按 F 切換全螢幕，Esc 退出全螢幕",
    "keyboard_ctrl_c_tip": "按 Ctrl+C 複製目前圖片到剪貼簿",
    "keyboard_rating_tip": "按 1~5 為目前圖片評分；再按一次取消",
    "keyboard_search_tip": "按 / 或 Ctrl+F 搜尋圖片名稱",
    "keyboard_favorite_tip": "按 0 切換目前圖片的愛心收藏",
    "keyboard_slideshow_tip": "按 S 開始/停止幻燈片播放",
    # 評分狀態
    "rating_set": "評分：{star}",
    "rating_cleared": "已清除評分",
    # 搜尋對話框
    "search_dialog_title": "搜尋圖片",
    "search_dialog_placeholder": "輸入關鍵字搜尋...",
    "search_open": "開啟",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "前往父資料夾",
    "right_click_menu_next_image": "下一張圖",
    "right_click_menu_previous_image": "上一張圖",
    "right_click_menu_delete_current": "刪除目前的圖",
    "right_click_menu_delete_selected": "刪除選取的圖",
    "right_click_menu_image_info": "圖片資訊",
    # Image info
    "image_info_filename": "檔名: {info}\n",
    "image_info_fullpath": "完整路徑: {full_path}\n",
    "image_info_image_size": "尺寸: {width} x {height}\n",
    "image_info_file_size": "檔案大小: {file_size_mb} MB\n",
    "image_info_file_created_time": "建立時間: {created_time}\n",
    "image_info_file_modified_time": "修改時間: {modified_time}\n",
    "image_info_messagebox_title": "圖片資訊",
    # Image info exif
    "image_info_exif_datatime_original": "拍攝時間: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "相機: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "鏡頭: {LensModel}\n",
    "image_info_exif_camera_focal_length": "焦段: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "光圈: {FNumber}\n",
    "image_info_exif_exposure_time": "快門: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "近期開啟選單",
    # Plugin
    "plugin_menu_title": "插件",
    "plugin_menu_loaded": "已載入的插件",
    "plugin_menu_no_plugins": "沒有載入任何插件",
    "plugin_menu_reload": "重新載入插件",
    "plugin_menu_open_folder": "開啟插件資料夾",
    "plugin_info_name": "名稱：{name}",
    "plugin_info_version": "版本：{version}",
    "plugin_info_author": "作者：{author}",
    "plugin_info_description": "說明：{description}",
    "plugin_info_languages": "支援語言：{languages}",
    "plugin_menu_manage": "管理插件",
    "plugin_manage_count": "已載入 {count} 個插件",
    "plugin_manage_select_hint": "選擇插件以檢視詳細資訊",
    "plugin_reload_confirm": "重新載入所有插件？這將卸載目前的插件並重新搜尋。",
    "plugin_reload_done": "已重新載入 {count} 個插件",
    "plugin_menu_download": "下載插件",
    # Plugin Downloader
    "plugin_dl_title": "下載插件",
    "plugin_dl_refresh": "重新整理",
    "plugin_dl_col_name": "插件",
    "plugin_dl_col_status": "狀態",
    "plugin_dl_download": "下載",
    "plugin_dl_reinstall": "重新安裝",
    "plugin_dl_delete": "刪除",
    "plugin_dl_close": "關閉",
    "plugin_dl_installed": "已安裝",
    "plugin_dl_not_installed": "未安裝",
    "plugin_dl_status_ready": "就緒",
    "plugin_dl_status_fetching": "正在取得插件列表...",
    "plugin_dl_status_found": "找到 {count} 個插件",
    "plugin_dl_status_error": "錯誤：{error}",
    "plugin_dl_status_downloading": "正在下載 {name}...",
    "plugin_dl_status_done": "已成功下載 {name}！",
    "plugin_dl_status_deleted": "已刪除 {name}。",
    "plugin_dl_restart_hint": "插件 '{name}' 已下載。請重新啟動 Imervue 以啟用。",
    "plugin_dl_delete_confirm_title": "刪除插件",
    "plugin_dl_delete_confirm": "確定要刪除插件 '{name}' 嗎？",
    # 右鍵選單
    "right_click_show_in_explorer": "在檔案總管中顯示",
    "right_click_copy_path": "複製路徑",
    "right_click_copy_image": "複製圖片",
    "right_click_rotate_cw": "順時針旋轉",
    "right_click_rotate_ccw": "逆時針旋轉",
    "right_click_set_wallpaper": "設為桌布",
    "right_click_compare": "比較圖片",
    "right_click_slideshow": "幻燈片播放",
    "right_click_slideshow_stop": "停止幻燈片",
    # 排序選單
    "sort_menu_title": "排序",
    "sort_by_name": "依檔名",
    "sort_by_modified": "依修改日期",
    "sort_by_created": "依建立日期",
    "sort_by_size": "依檔案大小",
    "sort_by_resolution": "依解析度",
    "sort_ascending": "升序",
    "sort_descending": "降序",
    # 篩選選單
    "filter_menu_title": "篩選",
    "filter_by_extension": "依副檔名",
    "filter_by_rating": "依評分",
    "filter_ext_all": "全部",
    "filter_ext_jpg": "JPEG",
    "filter_ext_png": "PNG",
    "filter_ext_bmp": "BMP",
    "filter_ext_tiff": "TIFF",
    "filter_ext_raw": "RAW",
    "filter_rating_all": "全部",
    "filter_rating_favorited": "已收藏",
    "filter_clear": "清除篩選",
    # 收藏
    "favorite_added": "\u2764 已收藏",
    "favorite_removed": "已取消收藏",
    # 比較
    "compare_title": "比較圖片",
    "compare_2": "比較 2 張",
    "compare_4": "比較 4 張",
    # EXIF 側邊欄
    "exif_filename": "檔案",
    "exif_filesize": "大小",
    "exif_created": "建立時間",
    "exif_modified": "修改時間",
    "exif_taken": "拍攝時間",
    "exif_make": "製造商",
    "exif_model": "型號",
    "exif_lens": "鏡頭",
    "exif_focal": "焦距",
    "exif_aperture": "光圈",
    "exif_shutter": "快門",
    "exif_iso": "ISO",
    "exif_ev": "曝光補償",
    "exif_wb": "白平衡",
    "exif_flash": "閃光燈",
    "exif_resolution": "解析度",
    "exif_no_data": "無 EXIF 資料",
    # 幻燈片
    "slideshow_title": "幻燈片播放",
    "slideshow_interval": "間隔（秒）：",
    "slideshow_fade": "淡入淡出過場",
    "slideshow_start": "開始",
    "slideshow_cancel": "取消",
    # 狀態列
    "status_loading_progress": "載入中 {current}/{total}...",
    "status_loading_image": "載入圖片中...",
    "status_ready": "就緒",
    # Toast
    "toast_path_copied": "已複製路徑",
    # 右鍵額外
    "right_click_edit_image": "編輯圖片",
    "right_click_batch": "批次操作",
    "batch_rename_title": "批次重新命名",
    "batch_rename_hint": "模板：{name} = 原始名稱，{n} = 序號，{ext} = 副檔名",
    "batch_rename_start": "起始編號：",
    "batch_rename_apply": "重新命名",
    "batch_rename_cancel": "取消",
    "batch_move_title": "移動 / 複製",
    "batch_move_mode": "模式",
    "batch_move_move": "移動",
    "batch_move_copy": "複製",
    "batch_move_apply": "套用",
    "batch_move_cancel": "取消",
    "batch_rotate_cw": "全部順時針旋轉",
    "batch_rotate_ccw": "全部逆時針旋轉",
    # 圖片編輯器
    "editor_title": "圖片編輯器",
    "editor_brightness": "亮度",
    "editor_contrast": "對比",
    "editor_saturation": "飽和度",
    "editor_apply_crop": "套用裁剪",
    "editor_rotate_cw": "順時針旋轉",
    "editor_rotate_ccw": "逆時針旋轉",
    "editor_reset": "重置",
    "editor_save_as": "另存為...",
    "editor_save": "儲存",
    "editor_saved": "已儲存！",
    # EXIF 編輯器
    "exif_edit_button": "編輯 EXIF",
    "exif_editor_title": "編輯 EXIF 元資料",
    "exif_editor_no_piexif": "需要 piexif 套件。\n安裝：pip install piexif",
    "exif_editor_fields": "元資料欄位",
    "exif_editor_save": "儲存",
    "exif_editor_cancel": "取消",
    "exif_editor_close": "關閉",
    "exif_editor_saved": "EXIF 已儲存！",
    "exif_edit_description": "描述",
    "exif_edit_artist": "作者",
    "exif_edit_copyright": "版權",
    "exif_edit_make": "製造商",
    "exif_edit_model": "型號",
    "exif_edit_user_comment": "使用者備註",
    # 匯出對話框
    "export_title": "匯出圖片",
    "export_format": "格式：",
    "export_quality": "品質：",
    "export_browse": "瀏覽...",
    "export_save": "儲存",
    "export_cancel": "取消",
    "export_saved": "匯出成功！",
    # 直方圖
    "histogram_toggle": "按 H 切換 RGB 直方圖",
    # 無損旋轉
    "lossless_rotate_cw": "無損順時針旋轉",
    "lossless_rotate_ccw": "無損逆時針旋轉",
    "lossless_rotate_done": "無損旋轉已儲存！",
    "lossless_rotate_fail": "無損旋轉失敗",
    # 右鍵選單新增
    "right_click_export": "匯出 / 另存為...",
    "right_click_lossless_rotate": "無損旋轉",
    # 動畫播放
    "anim_play": "播放",
    "anim_pause": "暫停",
    "anim_frame_prev": "上一幀",
    "anim_frame_next": "下一幀",
    "anim_frame_indicator": "幀 {current}/{total}",
    "anim_speed": "速度: {speed}x",
    # 檔案關聯
    "file_assoc_menu": "檔案關聯",
    "file_assoc_register": "註冊「以 Imervue 開啟」",
    "file_assoc_unregister": "移除檔案關聯",
    "file_assoc_done": "檔案關聯已註冊！",
    "file_assoc_removed": "檔案關聯已移除！",
    "file_assoc_need_admin": "需要管理員權限",
    # 多視窗
    "menu_new_window": "新視窗",
    # 適應模式
    "fit_width": "適應寬度",
    "fit_height": "適應高度",
    "keyboard_w_tip": "按 W 適應寬度，Shift+W 適應高度",
    # 額外快捷鍵提示
    "keyboard_h_tip": "在深度縮放模式下按 H 切換 RGB 直方圖",
    "keyboard_ctrl_v_tip": "按 Ctrl+V 從剪貼簿貼上圖片",
    "keyboard_anim_play_tip": "按空白鍵播放/暫停動畫圖片（GIF/APNG/WebP）",
    "keyboard_anim_frame_tip": "按 < / > 逐幀瀏覽動畫",
    "keyboard_anim_speed_tip": "按 [ / ] 減慢/加快動畫播放速度",
    # 書籤
    "bookmark_title": "書籤",
    "bookmark_open": "開啟",
    "bookmark_remove": "移除",
    "bookmark_clear": "清空全部",
    "bookmark_close": "關閉",
    "bookmark_count": "{count} 張已收藏圖片",
    "bookmark_added": "\u2605 已收藏",
    "bookmark_removed": "已取消收藏",
    "bookmark_add_current": "新增收藏",
    "bookmark_remove_current": "取消收藏",
    "bookmark_clear_confirm_title": "清空書籤",
    "bookmark_clear_confirm": "確定清空所有書籤？",
    "keyboard_b_tip": "按 B 切換當前圖片的收藏狀態",
    # SVG
    "filter_ext_svg": "SVG",
    # 標籤與相簿
    "tag_album_title": "標籤與相簿",
    "tag_tab_tags": "標籤",
    "tag_tab_albums": "相簿",
    "tag_close": "關閉",
    "tag_count": "{count} 個標籤",
    "tag_create": "新增標籤",
    "tag_rename": "重新命名",
    "tag_delete": "刪除",
    "tag_images": "標籤中的圖片：",
    "tag_remove_image": "從標籤移除",
    "tag_filter": "在檢視器中顯示",
    "tag_create_prompt": "標籤名稱：",
    "tag_rename_prompt": "新名稱：",
    "tag_delete_confirm_title": "刪除標籤",
    "tag_delete_confirm": "確定刪除標籤「{name}」？",
    "tag_menu_title": "標籤",
    "tag_create_and_add": "+ 新增標籤...",
    "album_count": "{count} 個相簿",
    "album_create": "新增相簿",
    "album_rename": "重新命名",
    "album_delete": "刪除",
    "album_images": "相簿中的圖片：",
    "album_remove_image": "從相簿移除",
    "album_view": "瀏覽相簿",
    "album_create_prompt": "相簿名稱：",
    "album_rename_prompt": "新名稱：",
    "album_delete_confirm_title": "刪除相簿",
    "album_delete_confirm": "確定刪除相簿「{name}」？",
    "album_menu_title": "相簿",
    "album_create_and_add": "+ 新增相簿...",
    "batch_tag_title": "加入標籤",
    "batch_album_title": "加入相簿",
    "filter_by_tag": "依標籤",
    "filter_by_album": "依相簿",
    "filter_no_tags": "（無標籤）",
    "filter_no_albums": "（無相簿）",
    "keyboard_t_tip": "按 T 開啟標籤與相簿管理",
    # 批次匯出
    "batch_export_title": "批次匯出",
    "batch_export_count": "已選取 {count} 張圖片",
    "batch_export_resize": "調整大小",
    "batch_export_max_width": "最大寬度：",
    "batch_export_max_height": "最大高度：",
    "batch_export_start": "匯出",
    "batch_export_done": "已匯出 {success}/{total} 張圖片",
    # GIF / 影片
    "gif_video_title": "製作 GIF / 影片",
    "gif_video_order": "拖曳排序（最上方 = 第一幀）：",
    "gif_video_move_up": "上移",
    "gif_video_move_down": "下移",
    "gif_video_settings": "設定",
    "gif_video_fps": "幀率：",
    "gif_video_width": "寬度：",
    "gif_video_height": "高度：",
    "gif_video_auto": "自動",
    "gif_video_loop": "無限循環",
    "gif_video_create": "建立",
    "gif_video_save": "另存為",
    "gif_video_done": "已建立：{path}",
}