chinese_word_dict = {
    "main_window_current_filename_format": "当前文件名：{name}",
    # File menu
    "main_window_open_image": "打开文件",
    "main_window_current_filename": "当前文件名：",
    "main_window_current_file": "文件",
    "main_window_open_folder": "打开文件夹",
    "main_window_exit": "退出",
    "main_window_tile_size": "缩略图大小",
    "main_window_select_folder": "选择文件夹",
    "main_window_select_image": "选择图片",
    "main_window_current_folder_format": "当前文件夹：{path}",
    "main_window_remove_undo_stack": "删除暂存撤销文件",
    # Language Menubar
    "menu_bar_language": "语言",
    "language_menu_bar_please_restart_messagebox": "请重新启动",
    "language_menu_bar_english": "英语",
    "language_menu_bar_traditional_chinese": "繁体中文",
    "language_menu_bar_chinese": "简体中文",
    "language_menu_bar_koren": "韩语",
    "language_menu_bar_japanese": "日语",
    # Tip menu
    "main_window_tip_menu": "使用说明",
    "main_window_mouse_tip_menu": "鼠标操作",
    "main_window_keyboard_tip_menu": "键盘操作",
    "mouse_control_middle_tip": "可以使用鼠标中键移动",
    "mouse_control_left_tip": "鼠标左键点击图片可以进入 Deep zoom 模式",
    "mouse_control_multi_select_tip": "按住鼠标左键可以在缩略图模式下多选图片",
    "keyboard_control_esc_tip": "Deep zoom 模式下可以按 ESC 退出",
    "keyboard_control_tile_arrow_up_tip": "缩略图模式下可以使用方向键的上来向上移动",
    "keyboard_control_tile_arrow_down_tip": "缩略图模式下可以使用方向键的下来向下移动",
    "keyboard_control_tile_arrow_left_tip": "缩略图模式下可以使用方向键的左来向左移动",
    "keyboard_control_tile_arrow_right_tip": "缩略图模式下可以使用方向键的右来向右移动",
    "keyboard_control_delete_tip": "按 Delete 将图片移至回收站（缩略图和 Deep zoom 模式均可）",
    "keyboard_r_tip": "Deep zoom 模式下按 R / Shift+R 顺时针/逆时针旋转",
    "keyboard_home_tip": "按 Home 重置缩放与位置至默认值",
    "keyboard_e_tip": "按 E 打开图片编辑器",
    "keyboard_undo_tip": "撤销上一步操作",
    "keyboard_redo_tip": "重做上一步被撤销的操作",
    "keyboard_arrow_lr_tip": "Deep zoom 模式下按左/右键切换图片",
    "keyboard_arrow_tile_tip": "缩略图模式下使用方向键浏览图片",
    "tip_mouse_middle": "中键",
    "tip_mouse_left_click": "左键点击",
    "tip_mouse_left_drag": "左键拖拽",
    "tip_mouse_right_desc": "打开右键菜单，提供多种操作功能",
    "tip_mouse_scroll_desc": "滚轮缩放或滚动缩略图",
    "tip_close": "关闭",
    "tip_show_shortcuts": "键盘与鼠标快捷键",
    "keyboard_f_tip": "按 F 切换全屏，Esc 退出全屏",
    "keyboard_ctrl_c_tip": "按 Ctrl+C 复制当前图片到剪贴板",
    "keyboard_rating_tip": "按 1~5 为当前图片评分；再按一次取消",
    "keyboard_search_tip": "按 / 或 Ctrl+F 搜索图片名称",
    "keyboard_favorite_tip": "按 0 切换当前图片的收藏状态",
    "keyboard_slideshow_tip": "按 S 开始/停止幻灯片播放",
    # 评分状态
    "rating_set": "评分：{star}",
    "rating_cleared": "已清除评分",
    # 搜索对话框
    "search_dialog_title": "搜索图片",
    "search_dialog_placeholder": "输入关键字搜索...",
    "search_open": "打开",
    # Right click menu
    "right_click_menu_go_to_parent_folder": "转到父文件夹",
    "right_click_menu_next_image": "下一张图",
    "right_click_menu_previous_image": "上一张图",
    "right_click_menu_delete_current": "删除当前的图",
    "right_click_menu_delete_selected": "删除选取的图",
    "right_click_menu_image_info": "图片信息",
    # Image info
    "image_info_filename": "文件名: {info}\n",
    "image_info_fullpath": "完整路径: {full_path}\n",
    "image_info_image_size": "尺寸: {width} x {height}\n",
    "image_info_file_size": "文件大小: {file_size_mb} MB\n",
    "image_info_file_created_time": "创建时间: {created_time}\n",
    "image_info_file_modified_time": "修改时间: {modified_time}\n",
    "image_info_messagebox_title": "图片信息",
    # Image info exif
    "image_info_exif_datatime_original": "拍摄时间: {DateTimeOriginal}\n",
    "image_info_exif_camera_model": "相机: {Make} {Model}\n",
    "image_info_exif_camera_lens_model": "镜头: {LensModel}\n",
    "image_info_exif_camera_focal_length": "焦距: {FocalLength}\n",
    "image_info_exif_camera_fnumber": "光圈: {FNumber}\n",
    "image_info_exif_exposure_time": "快门: {ExposureTime}\n",
    "image_info_exif_iso": "ISO: {ISOSpeedRatings}",
    # Recent menu
    "recent_menu_title": "近期打开菜单",
    # Plugin
    "plugin_menu_title": "插件",
    "plugin_menu_loaded": "已加载的插件",
    "plugin_menu_no_plugins": "没有加载任何插件",
    "plugin_menu_reload": "重新加载插件",
    "plugin_menu_open_folder": "打开插件文件夹",
    "plugin_info_name": "名称：{name}",
    "plugin_info_version": "版本：{version}",
    "plugin_info_author": "作者：{author}",
    "plugin_info_description": "说明：{description}",
    "plugin_info_languages": "支持语言：{languages}",
    "plugin_menu_manage": "管理插件",
    "plugin_manage_count": "已加载 {count} 个插件",
    "plugin_manage_select_hint": "选择插件以查看详细信息",
    "plugin_reload_confirm": "重新加载所有插件？这将卸载当前的插件并重新搜索。",
    "plugin_reload_done": "已重新加载 {count} 个插件",
    "plugin_menu_download": "下载插件",
    # Plugin Downloader
    "plugin_dl_title": "下载插件",
    "plugin_dl_refresh": "刷新",
    "plugin_dl_col_name": "插件",
    "plugin_dl_col_status": "状态",
    "plugin_dl_download": "下载",
    "plugin_dl_reinstall": "重新安装",
    "plugin_dl_delete": "删除",
    "plugin_dl_close": "关闭",
    "plugin_dl_installed": "已安装",
    "plugin_dl_not_installed": "未安装",
    "plugin_dl_status_ready": "就绪",
    "plugin_dl_status_fetching": "正在获取插件列表...",
    "plugin_dl_status_found": "找到 {count} 个插件",
    "plugin_dl_status_error": "错误：{error}",
    "plugin_dl_status_downloading": "正在下载 {name}...",
    "plugin_dl_status_done": "已成功下载 {name}！",
    "plugin_dl_status_deleted": "已删除 {name}。",
    "plugin_dl_restart_hint": "插件 '{name}' 已下载。请重新启动 Imervue 以激活。",
    "plugin_dl_delete_confirm_title": "删除插件",
    "plugin_dl_delete_confirm": "确定要删除插件 '{name}' 吗？",
    # 右键菜单
    "right_click_show_in_explorer": "在文件资源管理器中显示",
    "right_click_copy_path": "复制路径",
    "right_click_copy_image": "复制图片",
    "right_click_rotate_cw": "顺时针旋转",
    "right_click_rotate_ccw": "逆时针旋转",
    "right_click_set_wallpaper": "设为壁纸",
    "right_click_compare": "比较图片",
    "right_click_slideshow": "幻灯片播放",
    "right_click_slideshow_stop": "停止幻灯片",
    # 排序菜单
    "sort_menu_title": "排序",
    "sort_by_name": "按文件名",
    "sort_by_modified": "按修改日期",
    "sort_by_created": "按创建日期",
    "sort_by_size": "按文件大小",
    "sort_by_resolution": "按分辨率",
    "sort_ascending": "升序",
    "sort_descending": "降序",
    # 筛选菜单
    "filter_menu_title": "筛选",
    "filter_by_extension": "按扩展名",
    "filter_by_rating": "按评分",
    "filter_ext_all": "全部",
    "filter_ext_jpg": "JPEG",
    "filter_ext_png": "PNG",
    "filter_ext_bmp": "BMP",
    "filter_ext_tiff": "TIFF",
    "filter_ext_raw": "RAW",
    "filter_rating_all": "全部",
    "filter_rating_favorited": "已收藏",
    "filter_clear": "清除筛选",
    # 收藏
    "favorite_added": "\u2764 已收藏",
    "favorite_removed": "已取消收藏",
    # 比较
    "compare_title": "比较图片",
    "compare_2": "比较 2 张",
    "compare_4": "比较 4 张",
    # EXIF 侧边栏
    "exif_filename": "文件",
    "exif_filesize": "大小",
    "exif_created": "创建时间",
    "exif_modified": "修改时间",
    "exif_taken": "拍摄时间",
    "exif_make": "制造商",
    "exif_model": "型号",
    "exif_lens": "镜头",
    "exif_focal": "焦距",
    "exif_aperture": "光圈",
    "exif_shutter": "快门",
    "exif_iso": "ISO",
    "exif_ev": "曝光补偿",
    "exif_wb": "白平衡",
    "exif_flash": "闪光灯",
    "exif_resolution": "分辨率",
    "exif_no_data": "无 EXIF 数据",
    # 幻灯片
    "slideshow_title": "幻灯片播放",
    "slideshow_interval": "间隔（秒）：",
    "slideshow_fade": "淡入淡出过渡",
    "slideshow_start": "开始",
    "slideshow_cancel": "取消",
    # 状态栏
    "status_loading_progress": "加载中 {current}/{total}...",
    "status_loading_image": "加载图片中...",
    "status_ready": "就绪",
    # Toast
    "toast_path_copied": "已复制路径",
    # 右键额外
    "right_click_edit_image": "编辑图片",
    "right_click_batch": "批量操作",
    "batch_rename_title": "批量重命名",
    "batch_rename_hint": "模板：{name} = 原始名称，{n} = 序号，{ext} = 扩展名",
    "batch_rename_start": "起始编号：",
    "batch_rename_apply": "重命名",
    "batch_rename_cancel": "取消",
    "batch_move_title": "移动 / 复制",
    "batch_move_mode": "模式",
    "batch_move_move": "移动",
    "batch_move_copy": "复制",
    "batch_move_apply": "应用",
    "batch_move_cancel": "取消",
    "batch_rotate_cw": "全部顺时针旋转",
    "batch_rotate_ccw": "全部逆时针旋转",
    # 图片编辑器
    "editor_title": "图片编辑器",
    "editor_brightness": "亮度",
    "editor_contrast": "对比度",
    "editor_saturation": "饱和度",
    "editor_apply_crop": "应用裁剪",
    "editor_rotate_cw": "顺时针旋转",
    "editor_rotate_ccw": "逆时针旋转",
    "editor_reset": "重置",
    "editor_save_as": "另存为...",
    "editor_save": "保存",
    "editor_saved": "已保存！",
    # EXIF 编辑器
    "exif_edit_button": "编辑 EXIF",
    "exif_editor_title": "编辑 EXIF 元数据",
    "exif_editor_no_piexif": "需要 piexif 包。\n安装：pip install piexif",
    "exif_editor_fields": "元数据字段",
    "exif_editor_save": "保存",
    "exif_editor_cancel": "取消",
    "exif_editor_close": "关闭",
    "exif_editor_saved": "EXIF 已保存！",
    "exif_edit_description": "描述",
    "exif_edit_artist": "作者",
    "exif_edit_copyright": "版权",
    "exif_edit_make": "制造商",
    "exif_edit_model": "型号",
    "exif_edit_user_comment": "用户备注",
    # 导出对话框
    "export_title": "导出图片",
    "export_format": "格式：",
    "export_quality": "质量：",
    "export_browse": "浏览...",
    "export_save": "保存",
    "export_cancel": "取消",
    "export_saved": "导出成功！",
    # 直方图
    "histogram_toggle": "按 H 切换 RGB 直方图",
    # 无损旋转
    "lossless_rotate_cw": "无损顺时针旋转",
    "lossless_rotate_ccw": "无损逆时针旋转",
    "lossless_rotate_done": "无损旋转已保存！",
    "lossless_rotate_fail": "无损旋转失败",
    # 右键菜单新增
    "right_click_export": "导出 / 另存为...",
    "right_click_lossless_rotate": "无损旋转",
    # 动画播放
    "anim_play": "播放",
    "anim_pause": "暂停",
    "anim_frame_prev": "上一帧",
    "anim_frame_next": "下一帧",
    "anim_frame_indicator": "帧 {current}/{total}",
    "anim_speed": "速度: {speed}x",
    # 文件关联
    "file_assoc_menu": "文件关联",
    "file_assoc_register": "注册\"以 Imervue 打开\"",
    "file_assoc_unregister": "移除文件关联",
    "file_assoc_done": "文件关联已注册！",
    "file_assoc_removed": "文件关联已移除！",
    "file_assoc_need_admin": "需要管理员权限",
    # 多窗口
    "menu_new_window": "新窗口",
    # 适应模式
    "fit_width": "适应宽度",
    "fit_height": "适应高度",
    "keyboard_w_tip": "按 W 适应宽度，Shift+W 适应高度",
    # 额外快捷键提示
    "keyboard_h_tip": "在深度缩放模式下按 H 切换 RGB 直方图",
    "keyboard_ctrl_v_tip": "按 Ctrl+V 从剪贴板粘贴图片",
    "keyboard_anim_play_tip": "按空格键播放/暂停动画图片（GIF/APNG/WebP）",
    "keyboard_anim_frame_tip": "按 < / > 逐帧浏览动画",
    "keyboard_anim_speed_tip": "按 [ / ] 减慢/加快动画播放速度",
    # 书签
    "bookmark_title": "书签",
    "bookmark_open": "打开",
    "bookmark_remove": "移除",
    "bookmark_clear": "清空全部",
    "bookmark_close": "关闭",
    "bookmark_count": "{count} 张已收藏图片",
    "bookmark_added": "\u2605 已收藏",
    "bookmark_removed": "已取消收藏",
    "bookmark_add_current": "添加收藏",
    "bookmark_remove_current": "取消收藏",
    "bookmark_clear_confirm_title": "清空书签",
    "bookmark_clear_confirm": "确定清空所有书签？",
    "keyboard_b_tip": "按 B 切换当前图片的收藏状态",
    # SVG
    "filter_ext_svg": "SVG",
    # 标签与相册
    "tag_album_title": "标签与相册",
    "tag_tab_tags": "标签",
    "tag_tab_albums": "相册",
    "tag_close": "关闭",
    "tag_count": "{count} 个标签",
    "tag_create": "新建标签",
    "tag_rename": "重命名",
    "tag_delete": "删除",
    "tag_images": "标签中的图片：",
    "tag_remove_image": "从标签移除",
    "tag_filter": "在查看器中显示",
    "tag_create_prompt": "标签名称：",
    "tag_rename_prompt": "新名称：",
    "tag_delete_confirm_title": "删除标签",
    "tag_delete_confirm": "确定删除标签「{name}」？",
    "tag_menu_title": "标签",
    "tag_create_and_add": "+ 新建标签...",
    "album_count": "{count} 个相册",
    "album_create": "新建相册",
    "album_rename": "重命名",
    "album_delete": "删除",
    "album_images": "相册中的图片：",
    "album_remove_image": "从相册移除",
    "album_view": "浏览相册",
    "album_create_prompt": "相册名称：",
    "album_rename_prompt": "新名称：",
    "album_delete_confirm_title": "删除相册",
    "album_delete_confirm": "确定删除相册「{name}」？",
    "album_menu_title": "相册",
    "album_create_and_add": "+ 新建相册...",
    "batch_tag_title": "添加到标签",
    "batch_album_title": "添加到相册",
    "filter_by_tag": "按标签",
    "filter_by_album": "按相册",
    "filter_no_tags": "（无标签）",
    "filter_no_albums": "（无相册）",
    "keyboard_t_tip": "按 T 打开标签与相册管理",
    # 批量导出
    "batch_export_title": "批量导出",
    "batch_export_count": "已选择 {count} 张图片",
    "batch_export_resize": "调整大小",
    "batch_export_max_width": "最大宽度：",
    "batch_export_max_height": "最大高度：",
    "batch_export_start": "导出",
    "batch_export_done": "已导出 {success}/{total} 张图片",
    # GIF / 视频
    "gif_video_title": "制作 GIF / 视频",
    "gif_video_order": "拖拽排序（最上方 = 第一帧）：",
    "gif_video_move_up": "上移",
    "gif_video_move_down": "下移",
    "gif_video_settings": "设置",
    "gif_video_fps": "帧率：",
    "gif_video_width": "宽度：",
    "gif_video_height": "高度：",
    "gif_video_auto": "自动",
    "gif_video_loop": "无限循环",
    "gif_video_create": "创建",
    "gif_video_save": "另存为",
    "gif_video_done": "已创建：{path}",
}
